@@ -16,6 +16,7 @@ Tested with Python 3.7, see requirements.txt
 import argparse
 import os
 import sys
+from pathlib import Path
 import time
 from contextlib import redirect_stdout
 from collections import namedtuple
@@ -126,7 +127,7 @@ def test_genhighD(setup, runsize, nkeep=2, outpath=None):
             fname = (
                 "Oarray_" + str(setup.factor_levels) + "_Nrun" + str(runsize) + ".csv"
             )
-            np.savetxt(outpath + fname, np.asarray(Asel), delimiter=",", fmt="%i")
+            np.savetxt(os.path.join(outpath,fname), np.asarray(Asel), delimiter=",", fmt="%i")
             fname = (
                 "Efficiencies_"
                 + str(setup.factor_levels)
@@ -134,7 +135,7 @@ def test_genhighD(setup, runsize, nkeep=2, outpath=None):
                 + str(runsize)
                 + ".csv"
             )
-            np.savetxt(outpath + fname, effs, delimiter=",")
+            np.savetxt(os.path.join(outpath, fname), effs, delimiter=",")
         return Asel, effs
 
 
@@ -244,8 +245,6 @@ def evaluate_design2(setup, Array, printopt=True, dir_out=None, plotgrid=True):
 	A-Eff  (main term and quadratic)
 	A1-Eff (only main terms)
 	A2-Eff (main, quadratic, and interaction terms)
-	Acor_can_avg average canonical correltaion efficiency
-	Acor_can_max maximal canonical correlation coefficient
 	If dir_out is not None: 
 	Tables of corraltions, level balance and two-main interaction balance
 	Plot of pairwise relationships
@@ -288,6 +287,7 @@ def evaluate_design2(setup, Array, printopt=True, dir_out=None, plotgrid=True):
     ### Calculate Two-Level Interaction Balance:
     twoleveleff, twolevelmin, Alevel2bal = calc_twofactorbalance(setup, Array)
     twoleveleff, twolevelmin = 100 * twoleveleff, 100 * twolevelmin
+    """
     # Calculate canonical correlation
     Acor_can = np.full((number_of_factors, number_of_factors), np.nan)
     try:
@@ -302,6 +302,7 @@ def evaluate_design2(setup, Array, printopt=True, dir_out=None, plotgrid=True):
     except:
         Acor_can_avg = np.nan
         Acor_can_max = np.nan
+    """
 
     if printopt:
         print("Center Balance : %.2f" % centereff)
@@ -315,19 +316,21 @@ def evaluate_design2(setup, Array, printopt=True, dir_out=None, plotgrid=True):
         print("A-efficiency : %.2f" % Aeff)
         print("A1-efficiency : %.2f" % A1eff)
         print("A2-efficiency : %.2f" % A2eff)
-        print("Average Canonical Corr: %.2f" % Acor_can_avg)
-        print("Maximum Canonical Corr : %.2f" % Acor_can_max)
+        #print("Average Canonical Corr: %.2f" % Acor_can_avg)
+        #print("Maximum Canonical Corr : %.2f" % Acor_can_max)
 
     # Save output daignostic tables
     if dir_out is not None:
         os.makedirs(dir_out, exist_ok=True)
         # Canonical Correlation
+        """
         df_Acor_can = pd.DataFrame(
             data=np.round(Acor_can, 4),
             columns=setup.factor_names,
             index=setup.factor_names,
         )
         df_Acor_can.to_csv(dir_out + "Table_Canonical_Correlation.csv")
+        """
         df_pearson = pd.DataFrame(
             data=np.round(Acor_pearson, 4),
             columns=setup.factor_names,
@@ -369,8 +372,8 @@ def evaluate_design2(setup, Array, printopt=True, dir_out=None, plotgrid=True):
         Aeff,
         A1eff,
         A2eff,
-        Acor_can_avg,
-        Acor_can_max,
+        #Acor_can_avg,
+        #Acor_can_max,
     )
     return efficiencies
 
@@ -535,11 +538,11 @@ def optimize_design(
     if outpath_nrun is not None:
         os.makedirs(outpath_nrun, exist_ok=True)
         fname = "EDarray_" + str(setup.factor_levels) + "_Nrun" + str(runsize) + ".csv"
-        np.savetxt(outpath_nrun + fname, A, delimiter=",", fmt="%i")
+        np.savetxt(os.path.join(outpath_nrun, fname), A, delimiter=",", fmt="%i")
         fname = (
             "Efficiencies_" + str(setup.factor_levels) + "_Nrun" + str(runsize) + ".csv"
         )
-        np.savetxt(outpath_nrun + fname, efficiencies, delimiter=",")
+        np.savetxt(os.path.join(outpath_nrun, fname), efficiencies, delimiter=",")
     return Asel, efficiencies
 
 
@@ -551,7 +554,7 @@ def eval_extarray(setup, path, infname):
 	setup: ExperimentalSetup
 	path, infname: input path and filename of array saved as csv file (without header or index)
 	"""
-    A = np.loadtxt(path + infname, delimiter=",")
+    A = np.loadtxt(os.path.join(path, infname), delimiter=",")
     effs = evaluate_design2(setup, A)
     effs = np.round(effs, 3)
     # centereff, leveleff, orthoeff, twoleveleff, twolevelmin, Deff, D1eff, D2eff, Aeff, A1eff, A2eff = effs
@@ -568,13 +571,13 @@ def eval_extarray(setup, path, infname):
         "A-Eff",
         "A1-Eff",
         "A2-Eff",
-        "Canonical-Eff",
-        "Canonical-Corr-max",
+        #"Canonical-Eff",
+        #"Canonical-Corr-max",
     ]
     df_eff = pd.DataFrame(data=effs.reshape(1, -1), columns=header)
     # Assuming infname for input array ends alerady with .csv :
     outfname = "Efficiencies_" + infname
-    df_eff.to_csv(path + outfname, index=False)
+    df_eff.to_csv(os.path.join(path,outfname), index=False)
 
 
 class ExperimentalSetup:
@@ -747,7 +750,7 @@ def post_evaluate(setup, inpath, outpath, nmin, nmax, ndelta):
 	"""
     # Need updated parameter and efficiencies calculation
     xrun = np.arange(nmin, nmax, ndelta)
-    effs_array = np.zeros((len(xrun), 13))
+    effs_array = np.zeros((len(xrun), 11))
     for i, irun, in enumerate(xrun):
         print("--------------------------------")
         print("Evaluation of array for " + str(irun) + " runs:")
@@ -776,14 +779,14 @@ def post_evaluate(setup, inpath, outpath, nmin, nmax, ndelta):
         "A-Eff",
         "A1-Eff",
         "A2-Eff",
-        "Canonical-Eff",
-        "Canonical-Corr-max",
+        #"Canonical-Eff",
+        #"Canonical-Corr-max",
     ]
     df_eff = pd.DataFrame(data=effs_array, columns=header)
     dfout = np.round(df_eff, 3)
     dfout["Nexp"] = xrun
     fname = "Efficiencies_" + str(setup.factor_levels) + "_combined.csv"
-    dfout.to_csv(outpath + fname, index=False)
+    dfout.to_csv(os.path.join(outpath, fname), index=False)
     plt.ioff()
     dfout.plot(
         "Nexp",
@@ -798,7 +801,7 @@ def post_evaluate(setup, inpath, outpath, nmin, nmax, ndelta):
         ],
         sort_columns=True,
     )
-    plt.savefig(outpath + "Efficiencies_" + str(setup.factor_levels) + ".png", dpi=300)
+    plt.savefig(os.path.join(outpath, "Efficiencies_" + str(setup.factor_levels) + ".png"), dpi=300)
     plt.close()
     return effs_array
 
@@ -855,7 +858,7 @@ def print_designselection_summary(results, fname_out=None):
         fout.close()
 
 
-Result = namedtuple("Result", ["name", "runsize", "effs"])
+#Result = namedtuple("Result", ["name", "runsize", "effs"])
 
 
 def main(
@@ -867,10 +870,12 @@ def main(
     delta_nrun=None,
 ):
     if outpath is None:
-        outpath = path
+        outpath = path = Path(path)
+    else:
+        outpath = Path(outpath)
 
     # Read-in experimental design specifications:
-    setup = ExperimentalSetup.read(path + fname_setup)
+    setup = ExperimentalSetup.read(os.path.join(path,fname_setup))
     # print(setup.level_values)
 
     # Calculate number of total possible combinations of all factors:
@@ -904,11 +909,11 @@ def main(
         print("You may want to consider a smaller runsize.")
     print("Total estimated runtime:  " + str(minutes) + "minutes")
     # xrun = np.arange(201,300,ndelta)
-    effs_array = np.zeros((len(xrun), 13))
+    effs_array = np.zeros((len(xrun), 11))
     for i, irun, in enumerate(xrun):
         print("--------------------------------")
         print("Optimizing array for " + str(irun) + " runs ...")
-        outpath_nrun = outpath + "DesignArray_Nrun" + str(int(irun)) + "/"
+        outpath_nrun = os.path.join(outpath, "DesignArray_Nrun" + str(int(irun)) + "/")
         Aopt, effs = optimize_design(
             setup, int(irun), runtime=maxtime_per_run, outpath_nrun=outpath_nrun
         )
@@ -933,14 +938,14 @@ def main(
         "A-Eff",
         "A1-Eff",
         "A2-Eff",
-        "Canonical-Eff",
-        "Canonical-Corr-max",
+        #"Canonical-Eff",
+        #"Canonical-Corr-max",
     ]
     df_eff = pd.DataFrame(data=effs_array, columns=header)
     dfout = np.round(df_eff, 3)
     dfout["Nexp"] = xrun
     fname = "Efficiencies_" + str(setup.factor_levels) + "_all3.csv"
-    dfout.to_csv(outpath + fname, index=False)
+    dfout.to_csv(os.path.join(outpath, fname), index=False)
 
     # dfout.plot("Nexp", ['Center Balance', 'Level Balance', 'Orthogonality', 'D-Eff', 'D1-Eff', 'A-Eff', 'E-Eff'], sort_columns = True)
     dfout.plot(
@@ -956,7 +961,7 @@ def main(
         sort_columns=True,
     )
     plt.ioff()
-    plt.savefig(outpath + "Efficiencies_" + str(setup.factor_levels) + ".png", dpi=300)
+    plt.savefig(os.path.join(outpath, "Efficiencies_" + str(setup.factor_levels) + ".png"), dpi=300)
     plt.close()
     # seems to be correlation  between orthogonality(levelbvalance) and D1 and
     # plt.scatter(effs_array[:,1], effs_array[:,5])
@@ -1037,8 +1042,7 @@ def main(
     # Convert exp arrays into design tables with user level values
     print("Saving minimum, optimal, and best design as experiment design tables...")
     for result in results.values():
-        fname_array = (
-            outpath
+        fname_array = (os.path.join(outpath,
             + "DesignArray_Nrun"
             + str(result.runsize)
             + "/"
@@ -1046,15 +1050,14 @@ def main(
             + str(setup.factor_levels)
             + "_Nrun"
             + str(result.runsize)
-            + ".csv"
+            + ".csv")
         )
-        fname_out = (
-            outpath
+        fname_out = (os.path.join(outpath
             + "Designtable_"
             + result.name
             + "_Nrun"
             + str(result.runsize)
-            + ".csv"
+            + ".csv")
         )
         array2valuetable(setup, fname_array, fname_out)
 
@@ -1062,7 +1065,7 @@ def main(
     print_designselection_summary(results)
     # and in addition print summary to file:
     print_designselection_summary(
-        results, fname_out=outpath + "Experiment_Design_selection_summary.txt"
+        results, fname_out=os.path.join(outpath, "Experiment_Design_selection_summary.txt")
     )
     print("")
     print("FINISHED")
